/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                              **** CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2012 - 2013
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                                  EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale06_2013_Alum_Cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2013_Alum_Cuest.txt
/*         as como el archivo Excale06_2013_Alum_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2013_Alum_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2013_Alum_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 12 DE DICIEMBRE DEL 2014
/*
/*  ****************************************************************************/




LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale06_2013_Alum_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     1         = "Urbana Pblica"
                       2         = "Rural Pblica"
                       3         = "Educacin Indgena"
                       4         = "Curso Comunitario"
                       5         = "Privada"
                       6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "UP"      = "Urbano Pblico"
                       "RP"      = "Rural Pblico"
                       "EI"      = "Educacin Indgena"
                       "CC"      = "Cursos Comunitarios"
                       "UPV"     = "Privados"
                       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE $entestF    "999"     ="Respuesta omitida";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edad_acF    98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE mes_nacF    1         = "Enero"
                       2         = "Febrero"
                       3         = "Marzo"
                       4         = "Abril"
                       5         = "Mayo"
                       6         = "Junio"
                       7         = "Julio"
                       8         = "Agosto"
                       9         = "Septiembre"
                       10        = "Octubre"
                       11        = "Noviembre"
                       12        = "Diciembre"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE edadF       99        = "Respuesta omitida";
     VALUE edadCF      1         = "11 aos o menos"
                       2         = "12 aos"
                       3         = "13 aos"
                       4         = "14 aos o ms"
                       9         = "Respuesta omitida";
     VALUE edadNF      1         = "Edad normativa"
                       2         = "Extra-edad"
                       9         = "Respuesta omitida";
     VALUE edadAF      0         = "Sin edad anticipada"
                       1         = "Edad anticipada"
                       9         = "Respuesta omitida";
     VALUE edadEF      0         = "Sin extra edad severa"
                       1         = "Extra edad severa"
                       9         = "Respuesta omitida";
     VALUE docenF      99999     = "Respuesta omitida";
     VALUE R1F         1         = "Menos de media hora"
                       2         = "Entre 30 y 60 minutos"
                       3         = "Entre 1 y 2 horas"
                       4         = "Ms de 2 horas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R2F         1         = "Me voy caminando"
                       2         = "Bicicleta, patineta, patines, etc."
                       3         = "Transporte pblico (camin, metro, combi o micro, autobs, taxi, etc.)"
                       4         = "En el camin de la escuela, en coche, moto o camioneta"
                       5         = "Uso un transporte distinto a todos los anteriores"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R3F         0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Muchas veces"
                       3         = "Siempre o casi siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R4F         1         = "De tierra"
                       2         = "De cemento o firme"
                       3         = "De mosaico, alfombra, loseta, duela u otro recubrimiento"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R5F         0         = "Ninguno"
                       1         = "1"
                       2         = "2"
                       3         = "3 o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R6F         1         = "1 o 2"
                       2         = "3 o 4"
                       3         = "5 o 6"
                       4         = "7 u 8"
                       5         = "9 o 10"
                       6         = "Entre 11 y 15"
                       7         = "Entre 16 y 25"
                       8         = "26 o ms"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE R7_8F       1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R9F         0         = "Nunca hemos salido de vacaciones"
                       1         = "A algn lugar dentro del estado donde vivo"
                       2         = "A algn lugar en otro estado del pas"
                       3         = "A otro pas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R10F        0         = "No"
                       1         = "S, en casa"
                       2         = "S, fuera de casa"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R11F        0         = "No trabajo"
                       1         = "S me pagan"
                       2         = "No me pagan"
                       3         = "No, pero me dan cosas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R12F        0         = "No trabajo"
                       1         = "Slo los fines de semana"
                       2         = "Slo durante las vacaciones"
                       3         = "Por poco rato cuando no estoy en la escuela"
                       4         = "La mayor parte del tiempo que no estoy en la escuela"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R13F        0         = "No s"
                       1         = "No fue a la escuela"
                       2         = "Primaria"
                       3         = "Secundaria"
                       4         = "Bachillerato o preparatoria"
                       5         = "Licenciatura (carrera universitaria)"
                       6         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R14F        1         = "S"
                       0         = "No"
                       2         = "No s"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R15F        0         = "No s"
                       1         = "No fue a la escuela"
                       2         = "Primaria"
                       3         = "Secundaria"
                       4         = "Bachillerato o preparatoria"
                       5         = "Licenciatura (carrera universitaria)"
                       6         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R16F        1         = "S"
                       0         = "No"
                       2         = "No s"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R17F        0         = "No s"
                       1         = "Primaria"
                       2         = "Secundaria"
                       3         = "Bachillerato o preparatoria"
                       4         = "Licenciatura (carrera universitaria)"
                       5         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R18F        1         = "Primaria"
                       2         = "Secundaria"
                       3         = "Bachillerato o preparatoria"
                       4         = "Licenciatura (carrera universitaria)"
                       5         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R19_20F     0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Muchas veces"
                       3         = "Siempre o casi siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R21F        0         = "Ninguno"
                       1         = "Como 10 libros"
                       2         = "Como 25 libros"
                       3         = "Como 50 libros"
                       4         = "Como 100 libros"
                       5         = "Ms de 100 libros"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R22F        1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R23F        0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Muchas veces"
                       3         = "Siempre o casi siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R24F        3         = "Mucho"
                       2         = "Ms o menos"
                       1         = "Poco"
                       0         = "Casi nada"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R25_26F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R27F        1         = "En espaol"
                       2         = "En una lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)"
                       3         = "En un idioma extranjero (francs, ingls, alemn u otro)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R28F        0         = "Ninguno"
                       1         = "1 ao"
                       2         = "2 aos"
                       3         = "3 aos"
                       4         = "4 aos o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R29F        0         = "Ninguno"
                       1         = "1"
                       2         = "2 o ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R30F        1         = "Solamente en esta escuela"
                       2         = "En 2 escuelas"
                       3         = "En 3 o ms escuelas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R31F        0         = "No"
                       1         = "S, una vez"
                       2         = "S, ms de una vez"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R32F        1         = "Tiene descarga directa de agua, slo hay que jalar la palanca"
                       2         = "Hay que echarle agua con cubeta"
                       3         = "No se le puede echar agua"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R33_40F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R41F        1         = "1"
                       2         = "2"
                       3         = "3"
                       4         = "4"
                       5         = "5"
                       6         = "6"
                       7         = "7"
                       8         = "8"
                       9         = "9"
                       10        = "10"
                       11        = "11"
                       12        = "12"
                       13        = "13"
                       14        = "14 o ms"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE R42F        1         = "1"
                       2         = "2"
                       3         = "3"
                       4         = "4"
                       5         = "5"
                       6         = "6"
                       7         = "7 o ms"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE R43_51F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R52_57F     0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Muchas veces"
                       3         = "Siempre o casi siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R58F        1         = "1"
                       2         = "2"
                       3         = "3"
                       4         = "4"
                       5         = "5"
                       6         = "6"
                       7         = "7"
                       8         = "8"
                       9         = "9"
                       10        = "10"
                       11        = "11"
                       12        = "12"
                       13        = "13"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";

RUN;






DATA INEE.Excale06_2013_Alum_Cuest;
   LENGTH
       NACIONAL         3
       ESCUELA          4
       ID_ENT           3
       NOM_ENT          $19
       ID_MOD           3
       MOD              $4
       ESTRATO          $7
       ENTEST           $6
       ALUMNO           5
       ID_INSTR         $15
       SEXO             3
       EDAD_AC          3
       MES_NAC          3
       EDAD             8
       EDAD_ACC         3
       EDAD_N           3
       EDAD_ANT         3
       EDAD_EES         3
       W_ALU            8
       DOCENTE          5
       AP001            3
       AP002            3
       AP003            3
       AP004            3
       AP005            3
       AP006            3
       AP007            3
       AP008            3
       AP009            3
       AP010            3
       AP011            3
       AP012            3
       AP013            3
       AP014            3
       AP015            3
       AP016            3
       AP017            3
       AP018            3
       AP019            3
       AP020            3
       AP021            3
       AP022            3
       AP023            3
       AP024            3
       AP025            3
       AP026            3
       AP027            3
       AP028            3
       AP029            3
       AP030            3
       AP031            3
       AP032            3
       AP033            3
       AP034            3
       AP035            3
       AP036            3
       AP037            3
       AP038            3
       AP039            3
       AP040            3
       AP041            3
       AP042            3
       AP043            3
       AP044            3
       AP045            3
       AP046            3
       AP047            3
       AP048            3
       AP049            3
       AP050            3
       AP051            3
       AP052            3
       AP053            3
       AP054            3
       AP055            3
       AP056            3
       AP057            3
       AP058            3
       WVARSTRR         3
       W_FSTR1          8
       W_FSTR2          8
       W_FSTR3          8
       W_FSTR4          8
       W_FSTR5          8
       W_FSTR6          8
       W_FSTR7          8
       W_FSTR8          8
       W_FSTR9          8
       W_FSTR10         8
       W_FSTR11         8
       W_FSTR12         8
       W_FSTR13         8
       W_FSTR14         8
       W_FSTR15         8
       W_FSTR16         8
       W_FSTR17         8
       W_FSTR18         8
       W_FSTR19         8
       W_FSTR20         8
       W_FSTR21         8
       W_FSTR22         8
       W_FSTR23         8
       W_FSTR24         8
       W_FSTR25         8
       W_FSTR26         8
       W_FSTR27         8
       W_FSTR28         8
       W_FSTR29         8
       W_FSTR30         8
       W_FSTR31         8
       W_FSTR32         8
       W_FSTR33         8
       W_FSTR34         8
       W_FSTR35         8
       W_FSTR36         8
       W_FSTR37         8
       W_FSTR38         8
       W_FSTR39         8
       W_FSTR40         8
       W_FSTR41         8
       W_FSTR42         8
       W_FSTR43         8
       W_FSTR44         8
       W_FSTR45         8
       W_FSTR46         8
       W_FSTR47         8
       W_FSTR48         8
       W_FSTR49         8
       W_FSTR50         8
       W_FSTR51         8
       W_FSTR52         8
       W_FSTR53         8
       W_FSTR54         8
       W_FSTR55         8
       W_FSTR56         8
       W_FSTR57         8
       W_FSTR58         8
       W_FSTR59         8
       W_FSTR60         8
       W_FSTR61         8
       W_FSTR62         8
       W_FSTR63         8
       W_FSTR64         8
       W_FSTR65         8
       W_FSTR66         8
       W_FSTR67         8
       W_FSTR68         8
       W_FSTR69         8
       W_FSTR70         8
       W_FSTR71         8
       W_FSTR72         8
       W_FSTR73         8
       W_FSTR74         8
       W_FSTR75         8
       W_FSTR76         8
       W_FSTR77         8
       W_FSTR78         8
       W_FSTR79         8
       W_FSTR80         8
       W_FSTR81         8
       W_FSTR82         8
       W_FSTR83         8
       W_FSTR84         8
       W_FSTR85         8
       W_FSTR86         8
       W_FSTR87         8
       W_FSTR88         8
       W_FSTR89         8
       W_FSTR90         8
       W_FSTR91         8
       W_FSTR92         8
       W_FSTR93         8
       W_FSTR94         8
       W_FSTR95         8
       W_FSTR96         8
       W_FSTR97         8
       W_FSTR98         8
       W_FSTR99         8
       W_FSTR100        8
;





INFILE alum MISSOVER LINESIZE = 1264;
   INPUT
       NACIONAL           1 - 1
       ESCUELA            2 - 5
       ID_ENT             6 - 7
       NOM_ENT            8 - 26
       ID_MOD            27 - 27
       MOD               28 - 31
       ESTRATO           32 - 38
       ENTEST            39 - 43
       ALUMNO            44 - 48
       ID_INSTR          49 - 63
       SEXO              64 - 64
       EDAD_AC           65 - 66
       MES_NAC           67 - 68
       EDAD              69 - 79
       EDAD_ACC          80 - 80
       EDAD_N            81 - 81
       EDAD_ANT          82 - 82
       EDAD_EES          83 - 83
       W_ALU             84 - 94
       DOCENTE           95 - 99
       AP001            100 - 100
       AP002            101 - 101
       AP003            102 - 102
       AP004            103 - 103
       AP005            104 - 104
       AP006            105 - 106
       AP007            107 - 107
       AP008            108 - 108
       AP009            109 - 109
       AP010            110 - 110
       AP011            111 - 111
       AP012            112 - 112
       AP013            113 - 113
       AP014            114 - 114
       AP015            115 - 115
       AP016            116 - 116
       AP017            117 - 117
       AP018            118 - 118
       AP019            119 - 119
       AP020            120 - 120
       AP021            121 - 121
       AP022            122 - 122
       AP023            123 - 123
       AP024            124 - 124
       AP025            125 - 125
       AP026            126 - 126
       AP027            127 - 127
       AP028            128 - 128
       AP029            129 - 129
       AP030            130 - 130
       AP031            131 - 131
       AP032            132 - 132
       AP033            133 - 133
       AP034            134 - 134
       AP035            135 - 135
       AP036            136 - 136
       AP037            137 - 137
       AP038            138 - 138
       AP039            139 - 139
       AP040            140 - 140
       AP041            141 - 142
       AP042            143 - 144
       AP043            145 - 145
       AP044            146 - 146
       AP045            147 - 147
       AP046            148 - 148
       AP047            149 - 149
       AP048            150 - 150
       AP049            151 - 151
       AP050            152 - 152
       AP051            153 - 153
       AP052            154 - 154
       AP053            155 - 155
       AP054            156 - 156
       AP055            157 - 157
       AP056            158 - 158
       AP057            159 - 159
       AP058            160 - 161
       WVARSTRR         162 - 164
       W_FSTR1          165 - 175
       W_FSTR2          176 - 186
       W_FSTR3          187 - 197
       W_FSTR4          198 - 208
       W_FSTR5          209 - 219
       W_FSTR6          220 - 230
       W_FSTR7          231 - 241
       W_FSTR8          242 - 252
       W_FSTR9          253 - 263
       W_FSTR10         264 - 274
       W_FSTR11         275 - 285
       W_FSTR12         286 - 296
       W_FSTR13         297 - 307
       W_FSTR14         308 - 318
       W_FSTR15         319 - 329
       W_FSTR16         330 - 340
       W_FSTR17         341 - 351
       W_FSTR18         352 - 362
       W_FSTR19         363 - 373
       W_FSTR20         374 - 384
       W_FSTR21         385 - 395
       W_FSTR22         396 - 406
       W_FSTR23         407 - 417
       W_FSTR24         418 - 428
       W_FSTR25         429 - 439
       W_FSTR26         440 - 450
       W_FSTR27         451 - 461
       W_FSTR28         462 - 472
       W_FSTR29         473 - 483
       W_FSTR30         484 - 494
       W_FSTR31         495 - 505
       W_FSTR32         506 - 516
       W_FSTR33         517 - 527
       W_FSTR34         528 - 538
       W_FSTR35         539 - 549
       W_FSTR36         550 - 560
       W_FSTR37         561 - 571
       W_FSTR38         572 - 582
       W_FSTR39         583 - 593
       W_FSTR40         594 - 604
       W_FSTR41         605 - 615
       W_FSTR42         616 - 626
       W_FSTR43         627 - 637
       W_FSTR44         638 - 648
       W_FSTR45         649 - 659
       W_FSTR46         660 - 670
       W_FSTR47         671 - 681
       W_FSTR48         682 - 692
       W_FSTR49         693 - 703
       W_FSTR50         704 - 714
       W_FSTR51         715 - 725
       W_FSTR52         726 - 736
       W_FSTR53         737 - 747
       W_FSTR54         748 - 758
       W_FSTR55         759 - 769
       W_FSTR56         770 - 780
       W_FSTR57         781 - 791
       W_FSTR58         792 - 802
       W_FSTR59         803 - 813
       W_FSTR60         814 - 824
       W_FSTR61         825 - 835
       W_FSTR62         836 - 846
       W_FSTR63         847 - 857
       W_FSTR64         858 - 868
       W_FSTR65         869 - 879
       W_FSTR66         880 - 890
       W_FSTR67         891 - 901
       W_FSTR68         902 - 912
       W_FSTR69         913 - 923
       W_FSTR70         924 - 934
       W_FSTR71         935 - 945
       W_FSTR72         946 - 956
       W_FSTR73         957 - 967
       W_FSTR74         968 - 978
       W_FSTR75         979 - 989
       W_FSTR76         990 - 1000
       W_FSTR77        1001 - 1011
       W_FSTR78        1012 - 1022
       W_FSTR79        1023 - 1033
       W_FSTR80        1034 - 1044
       W_FSTR81        1045 - 1055
       W_FSTR82        1056 - 1066
       W_FSTR83        1067 - 1077
       W_FSTR84        1078 - 1088
       W_FSTR85        1089 - 1099
       W_FSTR86        1100 - 1110
       W_FSTR87        1111 - 1121
       W_FSTR88        1122 - 1132
       W_FSTR89        1133 - 1143
       W_FSTR90        1144 - 1154
       W_FSTR91        1155 - 1165
       W_FSTR92        1166 - 1176
       W_FSTR93        1177 - 1187
       W_FSTR94        1188 - 1198
       W_FSTR95        1199 - 1209
       W_FSTR96        1210 - 1220
       W_FSTR97        1221 - 1231
       W_FSTR98        1232 - 1242
       W_FSTR99        1243 - 1253
       W_FSTR100       1254 - 1264
;






LABEL
      NACIONAL      = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA       = "Identificador de la escuela"
      ID_ENT        = "Entidad federativa (identificador numrico)"
      NOM_ENT       = "Entidad federativa"
      ID_MOD        = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD           = "Estrato escolar o Modalidad educativa"
      ESTRATO       = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST        = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO        = "Identificador del alumno"
      ID_INSTR      = "Identificador del cuadernillo de examen"
      SEXO          = "Sexo del alumno"
      EDAD_AC       = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC       = "Mes de nacimiento del alumno"
      EDAD          = "Edad del alumno al mes de mayo de 2013, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
      EDAD_ACC      = "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
      EDAD_N        = "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
      EDAD_ANT      = "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
      EDAD_EES      = "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
      W_ALU         = "Peso muestral o ponderador del alumno"
      DOCENTE       = "Identificador del docente que imparte clases al alumno"
      AP001         = "Cunto tiempo tardas en llegar de tu casa a la escuela?"
      AP002         = "La mayora de las veces, qu transporte utilizas para llegar a la escuela?"
      AP003         = "Para tener agua dentro de tu casa (para cocinar, baarte, lavar trastos, etc.), debes salir a buscarla?"
      AP004         = "De qu material es la mayor parte del piso que est dentro de tu casa?"
      AP005         = "Cuntos cuartos de bao hay en la casa donde vives?"
      AP006         = "Cuntos focos hay en la casa donde vives (incluyendo los de las lmparas)?"
      AP007         = "En la casa donde vives, duermen tres personas o ms en un mismo cuarto?"
      AP008         = "Has recibido o recibes beca del Programa Oportunidades?"
      AP009         = "La ltima vez que saliste de vacaciones con tu familia, a dnde fueron?"
      AP010         = "Adems de asistir a la escuela, trabajas?"
      AP011         = "Te pagan por trabajar?"
      AP012         = "Cundo trabajas?"
      AP013         = "Hasta qu grado estudi tu padre?"
      AP014         = "Tu pap trabaja y recibe un pago por ello?"
      AP015         = "Hasta qu grado estudi tu madre?"
      AP016         = "Tu mam trabaja y recibe un pago por ello?"
      AP017         = "Hasta qu grado les gustara a tus padres que t estudiaras?"
      AP018         = "A ti, hasta qu grado te gustara estudiar?"
      AP019         = "Alguien en tu casa est al pendiente de que hagas la tarea?"
      AP020         = "Alguien en tu casa te ayuda a resolver tus dudas de la escuela o a hacer la tarea?"
      AP021         = "Aproximadamente, cuntos libros hay en tu casa? (no incluyas ni revistas, ni peridicos, ni tus libros escolares)"
      AP022         = "Has tomado alguna clase fuera de la escuela (de idiomas, danza, deportes,computacin, etc.)?"
      AP023         = "Algn adulto de tu casa lee libros, peridicos, revistas, etc.?"
      AP024         = "A ti, te gusta leer?"
      AP025         = "Tus padres o abuelos hablan alguna lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)?"
      AP026         = "T sabes hablar alguna lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)?"
      AP027         = "En qu idioma aprendiste a hablar?"
      AP028         = "Cuntos aos fuiste al preescolar, knder o jardn de nios?"
      AP029         = "Desde que entraste a la primaria, has repetido algn grado?"
      AP030         = "Desde que entraste a la primaria, en cuntas escuelas has estudiado?"
      AP031         = "Desde que entraste a la primaria, te has cambiado de pueblo o ciudad?"
      AP032         = "El bao, escusado o letrina de tu casa"
      AP033         = "Tienen las siguientes cosas en tu casa?: Conexin a internet"
      AP034         = "Tienen las siguientes cosas en tu casa?: Televisin por cable o satelital"
      AP035         = "Tienen las siguientes cosas en tu casa?: Lnea telefnica"
      AP036         = "Tienen las siguientes cosas en tu casa?: Automvil o camioneta"
      AP037         = "Tienen las siguientes cosas en tu casa?: Computadora"
      AP038         = "Tienen las siguientes cosas en tu casa?: Lavadora de ropa"
      AP039         = "Tienen las siguientes cosas en tu casa?: Horno de microondas"
      AP040         = "Tienen las siguientes cosas en tu casa?: DVD, Blu-ray o videocasetera"
      AP041         = "Contndote a ti, cuntas personas viven en tu casa?"
      AP042         = "Cuntas personas de las que viven en tu casa trabajan y reciben un pago por ello?"
      AP043         = "Para hacer la tarea o estudiar en casa tienes un lugar silencioso?"
      AP044         = "Para hacer la tarea o estudiar en casa tienes una mesa y una silla?"
      AP045         = "Para hacer la tarea o estudiar en casa tienes buena iluminacin?"
      AP046         = "Para hacer la tarea o estudiar en casa tienes un espacio donde guardar tus materiales de la escuela?"
      AP047         = "Tienes en tu casa las siguientes cosas?: Papel y lpices, adems de los que usas para la escuela"
      AP048         = "Tienes en tu casa las siguientes cosas?: Colores o pinturas, tijeras o pegamento para tu uso"
      AP049         = "Tienes en tu casa las siguientes cosas?: Juegos de mesa (lotera, memoria, rompecabezas, ajedrez, domin, etc.)"
      AP050         = "Tienes en tu casa las siguientes cosas?: Computadora disponible para que t la utilices"
      AP051         = "Tienes en tu casa las siguientes cosas?: Libros o materiales que te ayuden a resolver tus dudas de la escuela (enciclopedias, internet, etc.)"
      AP052         = "Con qu frecuencia haces estas cosas con tu familia?: Leemos un libro o revista"
      AP053         = "Con qu frecuencia haces estas cosas con tu familia?: Vamos al cine o al teatro"
      AP054         = "Con qu frecuencia haces estas cosas con tu familia?: Escuchamos msica"
      AP055         = "Con qu frecuencia haces estas cosas con tu familia?: Vamos a museos"
      AP056         = "Con qu frecuencia haces estas cosas con tu familia?: Vamos a espectculos musicales o de danza"
      AP057         = "Con qu frecuencia haces estas cosas con tu familia?: Navegamos por internet"
      AP058         = "Cuntos aos tienes viviendo en el mismo pueblo o ciudad donde vives ahora?"
      WVARSTRR      = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;






FORMAT
       NACIONAL          1.
       ESCUELA           4.
       ID_ENT            id_entF.
       NOM_ENT           $char19.
       ID_MOD            id_modF.
       MOD               $modF.
       ESTRATO           $char7.
       ENTEST            $entestF.
       ALUMNO            5.
       ID_INSTR          $char15.
       SEXO              sexoF.
       EDAD_AC           edad_acF.
       MES_NAC           mes_nacF.
       EDAD              edadF.
       EDAD_ACC          edadCF.
       EDAD_N            edadNF.
       EDAD_ANT          edadAF.
       EDAD_EES          edadEF.
       DOCENTE           docenF.
       AP001             R1F.
       AP002             R2F.
       AP003             R3F.
       AP004             R4F.
       AP005             R5F.
       AP006             R6F.
       AP007             R7_8F.
       AP008             R7_8F.
       AP009             R9F.
       AP010             R10F.
       AP011             R11F.
       AP012             R12F.
       AP013             R13F.
       AP014             R14F.
       AP015             R15F.
       AP016             R16F.
       AP017             R17F.
       AP018             R18F.
       AP019             R19_20F.
       AP020             R19_20F.
       AP021             R21F.
       AP022             R22F.
       AP023             R23F.
       AP024             R24F.
       AP025             R25_26F.
       AP026             R25_26F.
       AP027             R27F.
       AP028             R28F.
       AP029             R29F.
       AP030             R30F.
       AP031             R31F.
       AP032             R32F.
       AP033             R33_40F.
       AP034             R33_40F.
       AP035             R33_40F.
       AP036             R33_40F.
       AP037             R33_40F.
       AP038             R33_40F.
       AP039             R33_40F.
       AP040             R33_40F.
       AP041             R41F.
       AP042             R42F.
       AP043             R43_51F.
       AP044             R43_51F.
       AP045             R43_51F.
       AP046             R43_51F.
       AP047             R43_51F.
       AP048             R43_51F.
       AP049             R43_51F.
       AP050             R43_51F.
       AP051             R43_51F.
       AP052             R52_57F.
       AP053             R52_57F.
       AP054             R52_57F.
       AP055             R52_57F.
       AP056             R52_57F.
       AP057             R52_57F.
       AP058             R58F.
       WVARSTRR          3.
;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = Fuera de rango o ilegible.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;
   IF  entest = "999" THEN  entest = .S;
   IF  Docente = 99999 THEN  Docente = .S;


   ARRAY perdidos1(5)  sexo edad_acc edad_n edad_ant edad_ant;
   DO  i=1 TO 5;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   ARRAY perdidos3(4)  AP006 AP041 AP042 AP058;
   DO  i=1 TO 4;
         IF perdidos3{i}= 97   THEN  perdidos3{i} = .N;
         IF perdidos3{i}= 98   THEN  perdidos3{i} = .M;
         IF perdidos3{i}= 99   THEN  perdidos3{i} = .S;
   END;


   ARRAY perdidos4(54)
                AP001 AP002 AP003 AP004 AP005 AP007 AP008 AP009 AP010
                AP011 AP012 AP013 AP014 AP015 AP016 AP017 AP018 AP019
                AP020 AP021 AP022 AP023 AP024 AP025 AP026 AP027 AP028
                AP029 AP030 AP031 AP032 AP033 AP034 AP035 AP036 AP037
                AP038 AP039 AP040 AP043 AP044 AP045 AP046 AP047 AP048
                AP049 AP050 AP051 AP052 AP053 AP054 AP055 AP056 AP057;
   DO  i=1 TO 54;
          IF perdidos4{i} = 8   THEN  perdidos4{i} = .M;
          IF perdidos4{i} = 9   THEN  perdidos4{i} = .S;
   END;

   drop i;
RUN;
